@@ -59,7 +59,7 @@
 #ifdef	W32
 #include <windows.h>
 #ifndef	ssize_t
-#define	ssize_t	long
+#define	ssize_t	int
 #endif
 #else
 #include <cstddef>
